:tocdepth: 3

========================
Octavia API v2 (Current)
========================

.. rest_expand_all::

--------------------
General API Overview
--------------------
.. include:: general.inc

--------------
Load Balancers
--------------
.. include:: loadbalancer.inc

---------
Listeners
---------
.. include:: listener.inc

-----
Pools
-----
.. include:: pool.inc

-------
Members
-------
.. include:: member.inc

--------------
Health Monitor
--------------
.. include:: healthmonitor.inc

-----------
L7 Policies
-----------
.. include:: l7policy.inc

--------
L7 Rules
--------
.. include:: l7rule.inc

------
Quotas
------
.. include:: quota.inc

---------
Providers
---------
.. include:: provider.inc

-------
Flavors
-------
.. include:: flavor.inc

---------------
Flavor Profiles
---------------
.. include:: flavorprofile.inc

------------------
Availability Zones
------------------
.. include:: availabilityzone.inc

--------------------------
Availability Zone Profiles
--------------------------
.. include:: availabilityzoneprofile.inc

--------
Amphorae
--------
.. include:: amphora.inc
